@@ -1,12 +1,11 @@
 `baseline` <-
-function(spect, sm.fac=10^15, neg.pen=sqrt(pi/2), 
-        max.iter=30, frac.changed=0.001, binsize=64, xvals=1:length(spect)){
+function(spect, sm.par=1.1E-9, neg.pen=sqrt(pi/2), k.biweight=6, 
+        max.iter=30, frac.changed=0.001, xvals=1:length(spect)){
     require(Matrix)
     L <- length(spect)
-    P <- L %/% binsize
-    s <- quantile(apply(matrix(spect[1:(P*binsize)],nrow=binsize),2,sd),0.25)
+    s <- .biweight(spect, K=k.biweight)$scale/qnorm(0.75)
     neg.pen <- neg.pen/s  
-    sm.fac <- sm.fac/s
+    sm.fac <- L^4*sm.par/s
 
     D0 <- new("dgCMatrix", Dim=as.integer(c(L,L)), p=as.integer(cumsum(c(0,3,4,rep(5,L-4),4,3))), 
         i=as.integer(c(0:2,0:3,as.vector(outer(0:4,0:(L-5),"+")), (L-4):(L-1), (L-3):(L-1))), 
