@@ -1,5 +1,5 @@
 `extract.pars` <-
-function(root.dir=".", par.file = "parameters.RData"){
+function(par.file = "parameters.RData", root.dir="."){
     load(paste(root.dir, "/", par.file, sep=""))
     ret <- list()
     for(i in setdiff(ls(),c("i","ret"))){
